@@ -3,8 +3,7 @@ import unittest
 import logging
 from StringIO import StringIO
 
-import runner
-
+from syncloud.app import runner
 
 class LoggingSubprocessTest(unittest.TestCase):
 
@@ -30,8 +29,7 @@ class LoggingSubprocessTest(unittest.TestCase):
         self.assertIn('INFO-foo', self.buffer.getvalue())
 
     def test_custom_stderr_log_level(self):
-        runner.call([sys.executable, "-c",
-                                'import sys; sys.stderr.write("foo\\n")'],
-                                self.logger,
-                                stderr_log_level=logging.WARNING)
+        runner.call([sys.executable, "-c", 'import sys; sys.stderr.write("foo\\n")'],
+                    self.logger,
+                    stderr_log_level=logging.WARNING)
         self.assertIn('WARNING-foo', self.buffer.getvalue())
\ No newline at end of file
